Crate grandpa_verifier_primitives

Crate grandpa_verifier_primitives 

Primitive types and traits used by the GRANDPA prover & verifier.

Modules

justification
GRANDPA justification utilities

Structs

ConsensusState
Previous light client state.
FinalityProof
Finality for block B is proved by providing:
ParachainHeaderProofs
Holds relavant parachain proofs for both header and timestamp extrinsic.
ParachainHeadersWithFinalityProof
Parachain headers with a Grandpa finality proof.

Functions

parachain_header_storage_key
This returns the storage key for a parachain header on the relay chain.

Type Aliases

Commit
A commit message for this chain’s block type.
DefaultHeader
The default header type that can be used with the GRANDPA prover.
Hash
Represents a Hash in this library