Primitive types and traits used by the GRANDPA prover & verifier.
Modules
- justification
- GRANDPA justification utilities
Structs
- Consensus
State - Previous light client state.
- Finality
Proof - Finality for block B is proved by providing:
- Parachain
Header Proofs - Holds relavant parachain proofs for both header and timestamp extrinsic.
- Parachain
Headers With Finality Proof - Parachain headers with a Grandpa finality proof.
Functions
- parachain_
header_ storage_ key - This returns the storage key for a parachain header on the relay chain.
Type Aliases
- Commit
- A commit message for this chain’s block type.
- Default
Header - The default header type that can be used with the GRANDPA prover.
- Hash
- Represents a Hash in this library